#
# spec file for package open-lldp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname liblldp_clif1
Name:           open-lldp
Summary:        Link Layer Discovery Protocol (LLDP) Agent
License:        GPL-2.0-only
Group:          System/Daemons
Version:        1.1+106.74c0600a8692
Release:        1.8
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libconfig-devel
BuildRequires:  libnl3-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
URL:            https://github.com/intel/openlldp
Source:         %{name}-v%{version}.tar.xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Provides:       dcbd = %{version}
Obsoletes:      dcbd < %{version}
Provides:       lldpad = %{version}
Obsoletes:      lldpad < %{version}
BuildRequires:  pkgconfig(systemd)
%systemd_requires

%description
This package contains the Link Layer Discovery Protocol (LLDP) Agent
with Data Center Bridging (DCB) for Intel(R) Network Connections
'lldpad' plus the configuration tools 'dcbtool' and 'lldptool'.

%package -n %{libname}
Summary:        Link Layer Discovery Protocol (LLDP) libraries
Group:          System/Libraries

%description -n %{libname}
This package contains the Link Layer Discovery Protocol (LLDP) libraries

%package devel
Summary:        Link Layer Discovery Protocol (LLDP) Agent
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       %{name} = %{version}
Provides:       dcbd-devel = %{version}
Obsoletes:      dcbd-devel < %{version}
Provides:       lldpad-devel = %{version}
Obsoletes:      lldpad-devel < %{version}

%description devel
This package contains the Link Layer Discovery Protocol (LLDP) Agent
with Data Center Bridging (DCB) for Intel(R) Network Connections
'lldpad' plus the configuration tools 'dcbtool' and 'lldptool'.

%prep
%setup -n %{name}-v%{version}

%build
%global optflags %{optflags} -fcommon
autoreconf -vi
%configure \
	--disable-static
%make_build

%check
%make_build check

%install
mkdir -p %{buildroot}/var/lib/lldpad
%makeinstall
# remove la archives
rm -rf %{buildroot}/%{_libdir}/*.la
ln -s service %{buildroot}%{_sbindir}/rclldpad

%post
%{fillup_only -n lldpad}
%service_add_post lldpad.service lldpad.socket

%pre
%service_add_pre lldpad.service lldpad.socket

%preun
%service_del_preun lldpad.service lldpad.socket

%postun
%service_del_postun lldpad.service lldpad.socket

%post -n %libname -p /sbin/ldconfig

%postun -n %libname -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%license COPYING
%doc README ChangeLog
%dir /var/lib/lldpad
%{_unitdir}/*
%{_sbindir}/*
%{_mandir}/man3/*
%{_mandir}/man8/*
%{_datadir}/bash-completion/completions/*

%files -n %libname
%defattr(-,root,root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so

%changelog
* Sun Jan 14 2024 lduncan@suse.com
- Update to version v1.1+106.74c0600a8692 (from upstream/branch-1.1):
  * lldpad: dcbx: prevent null dereference in dcbx_free_data
  * lldpad: ieee8023: reorder disabling pMAC and disabling MM TX
  * uapi: Provide a copy of const.h
  * dcbx: Fix use-after-free
  * dcbx: Fix NULL pointer dereference
  * ChangeLog: mention Additional Ethernet Capabilities TLV
  * lldptool: add man page for Additional Ethernet Capabilities TLV
  * lldptool: add CLI interface for Additional Ethernet Capabilities TLV
  * lldpad: ieee8023: allow changing the addFragSize advertisement
  * lldpad: ieee8023: add Additional Ethernet Capabilities TLV logic
  * lldpad: ieee8023: make ieee8023_data() return a pointer to ieee8023_user_data
  * lldpad: ethtool netlink accessors for MAC merge layer
  * lldpad: ieee8023: add basic rchange procedure
  * uapi: copy ethtool definitions for MAC Merge layer from Linux
  * uapi: update linux/netlink.h copy
  * uapi: import ethtool kernel headers from net-next
  * dcbx: Fix leak when receiving legacy TLVs with mismatched mode
  * lldp: Reject frames with duplicate TLVs
  * dcbx: Free manifest in rchange callback
  * dcbx: Avoid memory leak if ifup is called twice
  * ctrl_iface: Fix a memory leak in ctrl_iface_deinit
  * lldp: Avoid sending uninitialized data
  * lldptool: fix null pointer deference
* Fri Oct 27 2023 lduncan@suse.com
- Update to version latest Intel upstream (v1.1+77.75e83b6fb98e, jsc#PED-6852):
  * lldpad: dcbx: prevent null dereference in dcbx_free_data
  * dcbx: Fix use-after-free
  * dcbx: Fix NULL pointer dereference
  * dcbx: Fix leak when receiving legacy TLVs with mismatched mode
  * lldp: Reject frames with duplicate TLVs
  * dcbx: Free manifest in rchange callback
  * dcbx: Avoid memory leak if ifup is called twice
  * ctrl_iface: Fix a memory leak in ctrl_iface_deinit
  * lldp: Avoid sending uninitialized data
  * lldptool: fix null pointer deference
  * Revert "Use interface index instead of name in libconfig"
  * Avoiding null pointer dereference
  * agent: reset frame status on message delete
  * basman: use return address when pulling address
  * 8021Qaz: check for rx block validity
  * 8021qaz: squelch initialization errors
  * macvtap: fix error condition
  * vdp22: convert command parsing to null term
* Wed Oct 26 2022 lduncan@suse.com
- Update to version v1.1+58.8ca361bab766:
  * clif: Include string.h for mem* function prototypes
  * basman: use return address when pulling address
  * Revert "Use interface index instead of name in libconfig"
  * 8021Qaz: check for rx block validity
  * 8021qaz: squelch initialization errors
  * macvtap: fix error condition
  * vdp22: convert command parsing to null term
* Mon Sep 20 2021 lduncan@suse.com
- Update to version v1.1+44.0f781b4162d3:
  * agent: reset frame status on message delete
  * Avoiding null pointer dereference
* Fri Jan  8 2021 lduncan@suse.com
- Update to version v1.1+36.e926f7172b96:
  * tx: rename variable
  * event_iface: only set rcv buf size if too small (bsc#1175570)
  * tx: when operating in rx-only mode don't send a port shutdown pdu
  * Update .travis.yml
  * vdp22: manpage typo
  * lldptool: fix manpage
  * lldp_head: remove all references
  * add_rtattr: only copy if data is provided
  * autoconf: convenience to setup asan and ubsan
  * Post 1.1 release
* Thu Dec 10 2020 lduncan@suse.com
- Update to version v1.1+18.0e969d0edcc4:
  * event_iface: only set rcv buf size if too small (bsc#1175570)
* Mon Nov  9 2020 lduncan@suse.com
- Update to version v1.1+15.ef8495548d04, by merging
  upstream version 1.1 + latest, including:
  * Fix merge error: remove bogus line
  * vdp22: manpage typo
  * lldptool: fix manpage
  * lldp_head: remove all references
  * add_rtattr: only copy if data is provided
  This removed the need for the patch disable-werror.patch.
* Sun Sep  6 2020 lduncan@suse.com
- Update to version v1.0.1+69.e8f522565f5a to removed commpiler
  and rpmlint complaints:
  * Fix bash-completion dir: don't use /etc
  * Fix compiler issue with strcpy(): use memcpy
  * Fix compiler complaint argument type mismatch.
  * Fix compiler complaint declaration vs function.
  * Fix compiler complaint copying to packed member.
  * add 'lldpad.socket' to the '%%service_*' macros in the SPEC
    file
* Fri Sep  4 2020 Lee Duncan <lduncan@suse.com>
- Moved sources from github.com/intel to github/openSUSE
  * upgrading to version v1.0.1+110.6009075a9fcc
  - merged in latest upstream (no API changes)
* Tue Aug  4 2020 hare@suse.de
- Update to version v1.0.1+63.f977e67 (bsc#1171284,bsc#1170745,bsc#1153520):
  * lldp/rx.c: Reset state machine variable in process_delete_info()
  * lldp: do not call 'assert' in rxProcessFrame()
  * ecp: allow for failure to create
  * lldp_mand: retrieve permanent mac address in get_mac()
  * lldp_util: use netlink to fetch mac address
  * lldp_util: drop get_macstr()
  * linux/if_link.h: Update and add bonding netlink definitions
* Mon Apr  6 2020 Martin Liška <mliska@suse.cz>
- Use -fcommon in order to fix boo#1160407.
* Fri Jan 24 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd directly:
  allow OBS to shortcut through the -mini flavors.
* Tue Nov 19 2019 hare@suse.com
- Update to version v1.0.1+102.4c7fcc3:
  * l2_packet: Guard ETH_P_LLDP define (edit: fixes bsc#1156545)
  * lldp_mand: retrieve permanent mac address in get_mac()
  * lldp_util: use netlink to fetch mac address
  * lldp_util: drop get_macstr()
  * linux/if_link.h: Update and add bonding netlink definitions
* Tue Nov 19 2019 hare@suse.com
- Update to version v1.0.1+95.3168e11:
  * Test with newer GCC 8 and 9 versions
  * RPM build is broken, so skip
  * Place the tarball in the right place
  * A tarball needs to be built after bootstrap.sh for use with RPM
  * Added missing steps for building an RPM
  * Finish off with testing building the RPM
  * Test package installation as well
  * Test under multiple GCC releases
  * Drop requirement for Travis CI testing with Clang
  * Support checking build with Travis CI
  * vdp-netlink: account for sizes properly
  * qbg: avoid warning for extra parens
  * qbg: port name is always a valid pointer
  * dcbx-nl: drop run_cmd
  * ecp: allow for failure to create
  * lldp_util: allow for null ifa_addr element
  * lldpad: Do not enable port if already enabled
  * Silent -Werror=address-of-packed-member warnings.
  * Come up with STRNCPY_TERMINATED (#25).
  * vdptool: fixed compile error for getline()
  * Fix #23 by off by one strncpy value.
  * 8021qaz: Block lldptool set operations if read only mode is on
  * 8021qaz: Add read only option for 8021qaz module
  * lldp: Allow lldptool to modify optional TLV's content
  * 8021qaz: Print dscp2prio map
  * autoconf: Add systemd support in configure.ac
  * rpm-spec: Add vdp22 man files to lldpad.spec.in
* Tue May 14 2019 Martin Liška <mliska@suse.cz>
- Add disable-werror.patch.
* Thu May  9 2019 Martin Liška <mliska@suse.cz>
- Disable -Werror (boo#1128299) and remove gcc9-fix-werror.patch.
* Tue Mar 19 2019 Martin Liška <mliska@suse.cz>
- Add gcc9-fix-werror.patch in order to fix bsc#1128299.
- Adjust project URL as we're using the Intel's fork.
* Mon Jan 14 2019 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Thu Jan 10 2019 hare@suse.de
- Update to git commit cb81e9541b5 (FATE#326034,bug#1104011)
  * 8021qaz: Remove unused variable
  * 8021qaz: Honor willing value from config file
  * lldpad: Support DSCP selectors in APP TLV's
  * Fix application tlv display
  * basman_clif: print the OID properly
  * ecp22: deinit l2_packet_data before freeing ecp22
  * DCB set state operation return value check
  * memleak on received TLVs from modules
  * Use interface index instead of name in libconfig
  * Fix 'is_valid_mac' to include mcast mac address
  * lldpad: Fix segfault in lldptool
  * Fixup disabling PG
  + open-lldp-v1.0.1+56.cb81e95.tar.xz
- Remove superseded files
  - open-lldp-1.0.1.tar.gz
  - open-lldp-git-update.patch.bz2
  - open-lldp-gcc5.patch
  - 0001-l2_linux_packet-correctly-process-return-value-of-ge.patch
  - 0002-lldpad-Only-set-Tx-adminStatus-if-interface-is-not-m.patch
* Mon Dec 11 2017 dimstar@opensuse.org
- Fix calling of fillup_only: it knows no -i parameter.
* Tue Feb 28 2017 dimstar@opensuse.org
- Don't use full URL as source, as the tarball does not exist at
  that location.
* Sat Feb 18 2017 kukuk@suse.com
- Remove obsolete insserv calls
* Mon Aug  3 2015 hare@suse.de
- Update to v1.0.1 (FATE#318849)
  * vpd22 updates
  * Include vpdtool
  * Support for OUI infrastructure in vpd22
  * Support for OUI infrastructure in vpdtool
  * Support for Cisco-specific OUI extensions in vpd22
  * Add vpdtool manpage
  * Add open-lldp-1.0.1.tar.gz
  * Remove open-lldp-0.9.46.tar.gz
  * Patches merged with upstream
  * Remove 0001-lldpad-print-verbose-error-messages.patch
  * Remove 0002-Move-to-libnl3.patch
- Update to latest git version
  * Automake fixes
  * Fix DCBX event generation from lldpad
  * Make TTL TLV configurable
  * Update open-lldp-git-update.patch.bz2
- Correctly process return value in get_perm_hwaddr (bsc#929171)
  * Add 0001-l2_linux_packet-correctly-process-return-value-of-ge.patch
- lldpad: Only set Tx adminStatus if interface is not managed
  (bsc#929171)
  * Add 0002-lldpad-Only-set-Tx-adminStatus-if-interface-is-not-m.patch
* Mon Mar 23 2015 crrodriguez@opensuse.org
- Fix build with gcc5 (open-lldp-gcc5.patch)
  * do not use -Werror
  * Use -fgnu89-inline as the code relies on the old semantics
* Wed May 21 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Wed May 14 2014 hare@suse.de
- Update to latest git version:
  * Include upstream version of VEPA migration issue (bnc#866282)
  * evb 22 test cases
  * vdp22 fixes
  * error message fixes
  * Fix interop issues with Juniper switches
- Fixup error messages in lldpad
  * Add 0001-lldpad-print-verbose-error-messages.patch
- Move to libnl3
  * Add 0002-Move-to-libnl3.patch
* Fri Mar 21 2014 hare@suse.de
- Fix VEPA migration issue (bnc#866282)
- Remove mkinitrd support
- Use bzip2 for open-lldp-git-update.patch
  * Add open-lldp-git-update.patch.bz2
  * Delete open-lldp-git-update.patch
* Tue Nov 19 2013 hare@suse.de
- Update to latest git version:
  * VPD22 support
  * Netlink fixes
* Thu Oct 10 2013 tchvatal@suse.com
- Provide and Obsolete old devel packages to avoid collisons.
- More whitespace cleanup.
* Fri Sep 13 2013 hare@suse.de
- Rename to open-lldp to be compliant with upstream
- Update to latest git version
  * Systemd integration
  * EVB fixes
- Update mkinitrd scriptlets
- Remove 'llpdad-makefile-fixup', merged with upstream
- Remove 'mkinitrd-stop.sh'
- Add open-lldp-git-update.patch to build properly
* Thu Aug  1 2013 tchvatal@suse.com
- Bump to 0.9.46 new upstream url found from fedora pkg:
  * Add IEEE802.1Qbg EVB module support
  * add and improve test code evbest/nltest
  * 8021qaz fix to work with hardware that does not support CEE DCBX
  * support lldpad running on bonded interfaces
  * pretty print support for VDP
  * new -p option to display lldpad process identifier
  * generate shared library liblldp_clif for applications to use
  * Add vdptest program
  * various link event fixes
  * Support for multiple agent types Nearest non-TPMR, Nearest customer bridge,
  and Nearest Bridge (always supported).
  * New man pages for VDP, EVB, and MED have been added.
  * DCBX improvements to remap DCB attributes when the host has less traffic
  classes then the peer.
  * Support to parse 802.1AB Organizationally Specific TLVs, Cisco Specific TLVs
  and the LLINK attributes of the DCBX CEE TLVs.
  * Support to reconfigure and set the MSAP subtype.
  * Additional gcc warnings turned on and miscellaneous fixes.
  * New client interface (abstract sockets) to support initrd stage
  * IEEE 802.1Qaz support has been added
  * EVB support has been added
  * Add iSCSI TLV support
  * Numerous bug fixes and code cleanup
  * Reworked netlink event handling to be more robust and handle dropped nlmsgs.
  * DCBx puts netdevice into linkmode until dcbx negotiation complete
- Remove obsolete patches, applied upstream/done differently by upstream:
  * lldpad-0.9.32-compile-fixes
  * lldpad-0.9.32-fix-buffer-overflow
  * lldpad-0.9.32-fix-error-in-pgid-construction
  * lldpad-0.9.32-fix-lldptool-segfault
  * lldpad-0.9.32-fix-race-condition
- Rebase patch to apply on current version:
  * lldpad-makefile-fixup
- Use unit file instead of init file to move under systemd
* Tue Jul 23 2013 ohering@suse.de
- Remove usage of absolute paths in mkinitrd scripts
- Add Requires(post/postun) to spec file
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Jul  6 2010 hare@suse.de
- Port rpm from SLES11 SP1.
* Fri May  7 2010 hare@suse.de
- Remove 'fix link flap' patch (bnc#603580)
* Mon Apr 26 2010 hare@suse.de
- Patches from bnc#599107:
  * fix race condition by opening client socket earlier
  * fix error in construction of the Priority Group TLV
  * fix link flap
  * fix segfault when handling lldptool arguments
  * fix buffer overflow in lldp-med inventory string
* Fri Mar 26 2010 kukuk@suse.de
- Fix requires of -devel subpackage
* Wed Mar 24 2010 hare@suse.de
- Fixup mkinitrd setup script to always create /var/lib/lldpad
* Tue Mar 23 2010 hare@suse.de
- Obsolete dcbd by lldpad version 0.9.32 (bnc#590487)
